#panels {
	position: relative;
	
}

html {
	overflow-y: scroll; /* This fixes the tooltips */ 
}

#panels-dialog-tabs {
	margin-bottom: -10px;
}

/* The Panel Type List */

.panel-type-list {
	margin: 0 -5px 10px -5px;
	min-height: 10px;
}

.panel-type-list .panel-type {
	width: 25%;
	
	-ms-box-sizing: border-box;
	-moz-box-sizing: border-box;
	-webkit-box-sizing: border-box;
	box-sizing: border-box;
	float: left;
	margin-bottom: 10px;
	padding: 0 5px;
}

.panel-type-list .panel-type h3 {
	height: 1.2em;
	
	color: #333333;
	font-size: 14px;
	margin: 0 0 7px 0;
}

.panel-type-list .panel-type small {
	height: 2.5em;
	
	display: block;
	font-size: 11px;
	line-height: 1.25em;
	overflow: hidden;
}

.panel-type-list .panel-type-wrapper {
	background: #ececec;
	background: -webkit-gradient(linear, left bottom, left top, color-stop(0, #ececec), color-stop(1, #f8f8f8));
	background: -ms-linear-gradient(bottom, #ececec, #f8f8f8);
	background: -moz-linear-gradient(center bottom, #ececec 0%, #f8f8f8 100%);
	background: -o-linear-gradient(#f8f8f8, #ececec);
	border: 1px solid #cccccc;
	-webkit-border-radius: 3px;
	-moz-border-radius: 3px;
	border-radius: 3px;
	-webkit-box-shadow: 0 1px 1px rgba(0,0,0,0.05);
	-moz-box-shadow: 0 1px 1px rgba(0,0,0,0.05);
	box-shadow: 0 1px 1px rgba(0,0,0,0.05);
	cursor: pointer;
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#f8f8f8', endColorstr='#ececec', GradientType=0);
	padding: 8px;
}

.panel-type-list .panel-type-wrapper:hover {
	border-color: #C0C0C0;
	box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
}

#panels-container .grid-wrapper h4 {
	margin: 5px 1px;
}

#panels-container .grid {
	position: relative;
	
	background: #edf8fe url("images/cell-selected.png") repeat;
	margin-bottom: 20px;
}

#panels-container .grid .ui-resizable-handle.ui-resizable-w {
	left: -11px;
	width: 10px;
	
	background: rgba(0, 150, 211, 0);
	cursor: move;
	-webkit-transition: background 0.25s ease-in-out;
	-moz-transition: background 0.25s ease-in-out;
	-o-transition: background 0.25s ease-in-out;
	transition: background 0.25s ease-in-out;
}

#panels-container .grid .ui-resizable-handle.ui-resizable-w:hover {
	background: rgba(0, 150, 211, 0.1);
}

#panels-container .grid .ui-resizable-handle.ui-resizable-w {
	background: rgba(0, 150, 211, 0.25);
}

#panels-container .grid .cell {
	position: absolute;
	top: 0;
	
	background: #e4eff4;
	border: 1px solid #bcccd2;
}

#panels-container .grid .cell.cell-selected {
	background: #d0eaf5 url("images/cell-selected.png") repeat;
	border-color: #a5c4ce;
	box-shadow: 0 0 4px rgba(80, 109, 118, 0.3);
}

#panels-container .grid .cell.first {
	margin-left: 0;
}

#panels-container .grid .cell.last {
	margin-right: 0;
}

#panels-container .grid .cell .cell-wrapper {
	-ms-box-sizing: border-box; /* 6px bottom to remove bottom margin from panels */ 
	-moz-box-sizing: border-box; /* 6px bottom to remove bottom margin from panels */ 
	-webkit-box-sizing: border-box; /* 6px bottom to remove bottom margin from panels */ 
	box-sizing: border-box;
	padding: 10px 10px 4px 10px; /* 6px bottom to remove bottom margin from panels */ 
}

#panels-container .grid .cell .cell-width {
	position: absolute;
	bottom: -13px;
	width: 100%;
	height: 11px;
	
	font-size: 9px;
	overflow: hidden;
}

#panels-container .grid .cell .cell-width-left {
	width: 5px;
	height: 11px;
	
	background: url(images/cell-width.png) no-repeat left top;
	float: left;
}

#panels-container .grid .cell .cell-width-right {
	width: 5px;
	height: 11px;
	
	background: url(images/cell-width.png) no-repeat left bottom;
	float: right;
}

#panels-container .grid .cell .cell-width-line {
	height: 11px;
	
	background: url(images/cell-width.png) repeat-x left -11px;
	margin: 0 5px;
}

#panels-container .grid .cell .cell-width-value {
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	
	text-align: center;
}

#panels-container .grid .cell .cell-width-value span {
	background: #f6f6f6;
	color: #848484;
	display: inline-block;
	font-size: 9px;
	line-height: 1;
	padding: 0 5px;
}

#panels-container .grid-container {
	position: relative;
	
}

#panels-container .grid-container .controls {
	line-height: 1;
	margin-bottom: 2px;
	text-align: right;
}

#panels-container .grid-container .controls .ui-button {
	margin-left: 5px;
}

#panels-container .grid-container .controls .grid-handle {
	cursor: move;
}

#so-panels-panels .ui-resizable-helper {
	position: absolute;
	
	background: #fff8bd;
	border: 1px solid #ecd800;
	-ms-box-sizing: border-box;
	-moz-box-sizing: border-box;
	-webkit-box-sizing: border-box;
	box-sizing: border-box;
	min-height: 100px;
}

#so-panels-panels .panels-container {
}

#so-panels-panels .panels-container .panel {
	background: #f8f8f8;
	background-image: -webkit-gradient(linear, left bottom, left top, from(#e9ebeb), to(#f8f8f8));
	background-image: -webkit-linear-gradient(bottom, #e9ebeb, #f8f8f8);
	background-image: -moz-linear-gradient(bottom, #e9ebeb, #f8f8f8);
	background-image: -o-linear-gradient(bottom, #e9ebeb, #f8f8f8);
	background-image: linear-gradient(to top, #e9ebeb, #f8f8f8);
	border: 1px solid;
	border-color: #c9c9c9 #c2c2c3 #babbbf #c1c2c3;
	-webkit-border-radius: 3px;
	-moz-border-radius: 3px;
	border-radius: 3px;
	-webkit-box-shadow: 0 1px 1px rgba(0, 0, 0, 0.08), inset 0 0 2px #ffffff;
	-moz-box-shadow: 0 1px 1px rgba(0, 0, 0, 0.08), inset 0 0 2px #ffffff;
	box-shadow: 0 1px 1px rgba(0, 0, 0, 0.08), inset 0 0 2px #ffffff;
	cursor: move;
	margin-bottom: 5px; /* End of .panel */ 
}

#so-panels-panels .panels-container .panel .panel-wrapper {
	position: relative;
	
	overflow: hidden;
	padding: 7px 9px;
}

#so-panels-panels .panels-container .panel h4 {
	height: 1em;
	
	color: #474747;
	cursor: pointer;
	display: inline-block;
	font-weight: 600;
	line-height: 1em;
	margin: 0 0 3px 0;
	margin-right: 15px;
	overflow: hidden;
	text-shadow: 0 1px 0 #FFF;
	white-space: nowrap;
}

#so-panels-panels .panels-container .panel h4 span {
	color: #999;
	display: inline-block;
	font-style: italic;
	font-weight: normal;
	margin-left: 12px;
	margin-right: 5px;
	text-shadow: 0 1px 0 #FFF;
}

#so-panels-panels .panels-container .panel .title a {
	display: none;
	margin-right: 3px;
}

#so-panels-panels .panels-container .panel .title .actions {
	position: absolute;
	top: 5px;
	right: 7px;
	
	background: #f3f3f3;
	background-image: -webkit-gradient(linear, left bottom, left top, from(#f1f2f2), to(#f5f6f6));
	background-image: -webkit-linear-gradient(bottom, #f1f2f2, #f5f6f6);
	background-image: -moz-linear-gradient(bottom, #f1f2f2, #f5f6f6);
	background-image: -o-linear-gradient(bottom, #f1f2f2, #f5f6f6);
	background-image: linear-gradient(to top, #f1f2f2, #f5f6f6);
	cursor: pointer;
	padding: 2px 2px 2px 15px;
	z-index: 10;
}

#so-panels-panels .panels-container .panel .title .actions:hover a {
	opacity: 1;
}

#so-panels-panels .panels-container .panel .title .actions a.delete {
	color: #FF0000;
}

#so-panels-panels .panels-container .panel .title .actions a.delete:hover {
	background: #FF0000;
	color: white;
}

#so-panels-panels .panels-container .panel:hover .title a {
	display: inline-block;
	opacity: 0.5;
}

#so-panels-panels .panels-container .panel.panel-being-dragged .title .actions {
	display: none;
}

#so-panels-panels .panels-container .panel small {
	height: 16px;
	
	display: block;
	overflow: hidden;
}

#so-panels-panels .panels-container .panel .form {
	display: none;
}

#so-panels-panels .panels-container .panel.ui-sortable-helper h4 {
	cursor: move;
}

#so-panels-panels .panels-container .ui-state-highlight {
	position: relative;
	height: 47px;
	
	background: #ddebef;
	border: 1px solid;
	border-color: #bcccd2;
	-webkit-border-radius: 3px;
	-moz-border-radius: 3px;
	border-radius: 3px;
	-moz-box-shadow: 0 1px 0 rgba(255, 255, 255, 0.7), inset 0 1px 2px rgba(0, 0, 0, 0.06);
	-webkit-box-shadow: 0 1px 0 rgba(255, 255, 255, 0.7), inset 0 1px 2px rgba(0, 0, 0, 0.06);
	box-shadow: 0 1px 0 rgba(255, 255, 255, 0.7), inset 0 1px 2px rgba(0, 0, 0, 0.06);
	margin-bottom: 5px;
}

/* Acts as a placeholder for dragging */

.cell-selected .panels-container .ui-state-highlight {
	background: #c8e1ec;
	border-color: #a4c4ce;
}

/* The Dialogs */

#panels-dialog,
#grid-setting-dialog,
#grid-add-dialog,
#grid-prebuilt-dialog {
	display: none;
}

#panels-dialog .panels-text-filter {
	margin-bottom: 10px;
}

/* The Tooltips */

.panels-tooltip {
	position: absolute;
	
	background: #1c1c1c;
	background: rgba(0, 0, 0, 0.8);
	-moz-border-radius: 3px;
	-webkit-border-radius: 3px;
	border-radius: 3px;
	color: white;
	font-size: 11px; /* Higher than the admin bar */ 
	padding: 4px 8px;
	z-index: 999999;
}

.panels-tooltip .pointer {
	position: absolute;
	bottom: -4px;
	left: 50%;
	width: 8px;
	height: 4px;
	
	background-image: url(images/tooltip-pointer.png);
	margin-left: -4px;
}

#content-panels {
	position: relative;
	
	z-index: 10;
}

#so-panels-panels {
	position: relative;
	
	border: 1px solid #CCC;
	z-index: 9;
}

#so-panels-panels h3.hndle {
	background: #eee;
	background-image: -webkit-gradient(linear, left bottom, left top, from(#e5e5e5), to(#f4f4f4));
	background-image: -webkit-linear-gradient(bottom, #e5e5e5, #f4f4f4);
	background-image: -moz-linear-gradient(bottom, #e5e5e5, #f4f4f4);
	background-image: -o-linear-gradient(bottom, #e5e5e5, #f4f4f4);
	background-image: linear-gradient(to top, #e5e5e5, #f4f4f4);
	border-bottom: 1px solid #CCC;
	padding: 4px 9px 4px 9px;
}

#so-panels-panels h3.hndle button {
	background: #eee;
	background-image: -webkit-gradient(linear, left bottom, left top, from(#e3e3e3), to(#ffffff));
	background-image: -webkit-linear-gradient(bottom, #e3e3e3, #ffffff);
	background-image: -moz-linear-gradient(bottom, #e3e3e3, #ffffff);
	background-image: -o-linear-gradient(bottom, #e3e3e3, #ffffff);
	background-image: linear-gradient(to top, #e3e3e3, #ffffff);
	border-color: #aaa;
	-webkit-box-shadow: 0 1px 1px rgba(0,0,0,0.06);
	-moz-box-shadow: 0 1px 1px rgba(0,0,0,0.06);
	box-shadow: 0 1px 1px rgba(0,0,0,0.06);
	display: inline-block;
	float: left;
	margin-right: 2px;
	padding: 7px 8px;
	visibility: visible;
}

#so-panels-panels h3.hndle button:active {
	-webkit-box-shadow: none;
	-moz-box-shadow: none;
	box-shadow: none;
}

#so-panels-panels h3.hndle button.preview {
	float: right;
}

#so-panels-panels .inside {
	padding: 5px 12px 5px 10px;
}

#wp-content-wrap.panels-active .switch-panels {
	background: #f4f4f4;
	border-color: #CCC #CCC #f4f4f4 #CCC;
	color: #333;
	z-index: 10;
}

#panels-undo-message {
	position: fixed;
	top: 23px;
	left: 50%;
	width: 250px;
	
	-moz-background-clip: padding-box;
	-webkit-background-clip: padding-box;
	background-clip: padding-box;
	-webkit-border-bottom-left-radius: 3px;
	border-bottom-left-radius: 3px;
	-webkit-border-bottom-right-radius: 3px;
	border-bottom-right-radius: 3px;
	border-top: none;
	-webkit-border-top-left-radius: 0;
	border-top-left-radius: 0;
	-webkit-border-top-right-radius: 0;
	border-top-right-radius: 0;
	margin-left: -125px;
	text-align: center;
	z-index: 100;
	-moz-border-radius-topright: 0;
	-moz-border-radius-bottomright: 3px;
	-moz-border-radius-bottomleft: 3px;
	-moz-border-radius-topleft: 0;
}

#panels-home-page #post-body {
	display: none;
}

#post-body-wrapper {
	background: url("images/loader.gif") no-repeat center center;
	min-height: 100px;
}

#so-panels-panels .dialog-form a {
	outline: 0;
}

.so-gallery-widget-select-attachments {
	float: right;
}

#panels-home-page #post-body-wrapper {
	margin-top: 10px;
}

/* The toggle switch */

#panels-toggle-switch {
	position: relative;
	width: 75px;
	height: 28px;
	
	background: #67afd8;
	-webkit-border-radius: 15px; /* Now for the off state */ 
	-moz-border-radius: 15px; /* Now for the off state */ 
	border-radius: 15px;
	-webkit-box-shadow: inset 0 1px 2px rgba(0,0,0,0.3); /* Now for the off state */ 
	-moz-box-shadow: inset 0 1px 2px rgba(0,0,0,0.3); /* Now for the off state */ 
	box-shadow: inset 0 1px 2px rgba(0,0,0,0.3);
	cursor: pointer;
	display: inline-block;
	margin-bottom: -6px;
	margin-left: 35px;
	overflow: hidden; /* Now for the off state */ 
}

#panels-toggle-switch .handle {
	position: absolute;
	top: 3px;
	left: 35px;
	width: 35px;
	height: 23px;
	
}

#panels-toggle-switch .on-text,
#panels-toggle-switch .off-text {
	position: absolute;
	top: 50%;
	
	font-size: 11px;
	font-weight: bold;
	line-height: 1;
	margin-top: -6px;
}

#panels-toggle-switch .on-text {
	left: 10px;
	
	color: #004f72;
	opacity: 1;
	text-shadow: 0 1px 0 rgba(255, 255, 255, 0.5);
}

#panels-toggle-switch .off-text {
	right: -23px;
	
	color: #919191;
	opacity: 0;
	text-shadow: 0 1px 0 rgba(255, 255, 255, 0.5);
}

#panels-toggle-switch.state-off {
	background: #e9e9e9;
}

#panels-toggle-switch.state-off .handle {
	left: 4px;
	
}

#panels-toggle-switch.state-off .on-text {
	left: -21px;
	
	opacity: 0;
}

#panels-toggle-switch.state-off .off-text {
	right: 8px;
	
	opacity: 1;
}

#panels-toggle-switch,
#panels-toggle-switch > * {
	-webkit-transition: all 0.22s ease;
	-moz-transition: all 0.22s ease;
	-o-transition: all 0.22s ease;
	transition: all 0.22s ease;
}

#panels-toggle-switch.state-on:hover {
	background: #6fb7e0;
}

#panels-toggle-switch.state-off:hover {
	background: #eeeeee;
}

#panels-toggle-switch.state-off.subtle-move:hover .handle {
	left: 7px;
	
}

#panels-toggle-switch.state-off.subtle-move:hover .off-text {
	right: 5px;
	
	opacity: 0.8;
}

/* The preview button */

#panels-home-page #post-body-content {
	position: relative;
	
}

#panels-home-page #post-preview {
	position: absolute;
	top: 0;
	right: 0;
	
	z-index: 10;
}

#grid-prebuilt-dialog {
	overflow: hidden;
}

#grid-prebuilt-dialog .chzn-results {
	height: 150px !important;
	
	overflow-y: auto;
}

/* The SiteOrigin link */

#siteorigin-widgets-link-wrapper {
	text-align: center;
}

#siteorigin-widgets-link {
	position: relative;
	
	background: #9ccc54;
	background: -webkit-gradient(linear, left bottom, left top, color-stop(0, #9ccc54), color-stop(1, #cbe385));
	background: -ms-linear-gradient(bottom, #9ccc54, #cbe385);
	background: -moz-linear-gradient(center bottom, #9ccc54 0%, #cbe385 100%);
	background: -o-linear-gradient(#cbe385, #9ccc54);
	border: 1px solid #83a44d;
	-webkit-border-radius: 3px;
	-moz-border-radius: 3px;
	border-radius: 3px;
	-webkit-box-shadow: 0 1px 2px rgba(0,0,0,0.15), inset 0 1px 0 rgba(255,255,255,0.5);
	-moz-box-shadow: 0 1px 2px rgba(0,0,0,0.15), inset 0 1px 0 rgba(255,255,255,0.5);
	box-shadow: 0 1px 2px rgba(0,0,0,0.15), inset 0 1px 0 rgba(255,255,255,0.5);
	color: #4f6920;
	display: inline-block;
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#cbe385', endColorstr='#9ccc54', GradientType=0);
	font-size: 13px;
	font-weight: bold;
	line-height: 16px;
	padding: 10px 15px;
	text-decoration: none;
	text-shadow: 0 1px 0 rgba(255, 255, 255, 0.5);
	-moz-transition: background 0.5s, color 0.5s, -moz-box-shadow 0.5;
	-webkit-transition: background 0.5s, color 0.5s, -webkit-box-shadow 0.5;
	-o-transition: background 0.5s, color 0.5s, -o-box-shadow 0.5;
	transition: background 0.5s, color 0.5s, box-shadow 0.5;
}

#siteorigin-widgets-link:hover {
	background: #a8d85f;
	background: -webkit-gradient(linear, left bottom, left top, color-stop(0, #a8d85f), color-stop(1, #d4ec8d));
	background: -ms-linear-gradient(bottom, #a8d85f, #d4ec8d);
	background: -moz-linear-gradient(center bottom, #a8d85f 0%, #d4ec8d 100%);
	background: -o-linear-gradient(#d4ec8d, #a8d85f);
	-webkit-box-shadow: inset 0 1px 0 rgba(255,255,255,0.5), 0 1px 2px rgba(0,0,0,0.25);
	-moz-box-shadow: inset 0 1px 0 rgba(255,255,255,0.5), 0 1px 2px rgba(0,0,0,0.25);
	box-shadow: inset 0 1px 0 rgba(255,255,255,0.5), 0 1px 2px rgba(0,0,0,0.25);
	color: #4a641b;
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#d4ec8d', endColorstr='#a8d85f', GradientType=0);
}

#siteorigin-widgets-link:active {
	background: #bbd975;
	background: -webkit-gradient(linear, left bottom, left top, color-stop(0, #bbd975), color-stop(1, #b3d46c));
	background: -ms-linear-gradient(bottom, #bbd975, #b3d46c);
	background: -moz-linear-gradient(center bottom, #bbd975 0%, #b3d46c 100%);
	background: -o-linear-gradient(#b3d46c, #bbd975);
	-webkit-box-shadow: 0 0 1px rgba(0,0,0,0.25);
	-moz-box-shadow: 0 0 1px rgba(0,0,0,0.25);
	box-shadow: 0 0 1px rgba(0,0,0,0.25);
	color: #476118;
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#b3d46c', endColorstr='#bbd975', GradientType=0);
	margin-bottom: -1px;
	margin-top: 1px;
	outline: none;
}

.panel-dialog h2.nav-tab-wrapper {
	margin-top: 0;
}

.panel-dialog h2.nav-tab-wrapper a.nav-tab {
	font-size: 11.5px;
	font-weight: bold;
	margin-right: 4px;
	padding: 4px 8px;
}

.panel-dialog h2.nav-tab-wrapper a.add-new {
	float: right;
	text-decoration: none;
}

/* Make sure the modals appear on the right layer */

.media-modal,
.appearance_page_so_panels_home_page .media-modal {
	z-index: 300010;
}

.media-modal-backdrop,
.appearance_page_so_panels_home_page .media-modal-backdrop {
	z-index: 300009;
}

#panels .message {
	background: #d0eaf5;
	border: 1px solid #a5c4ce;
	margin-bottom: 15px;
	padding: 5px 10px;
}

#panels .message p {
	margin: 0;
}

/* jQuery UI Styling */

/* jQuery UI Button */

#panels .ui-button,
#add-to-panels .ui-button,
.ui-dialog.panels-admin-dialog .ui-dialog-titlebar-close {
	position: relative;
	
	background: #e3e3e3;
	background: -webkit-gradient(linear, left bottom, left top, color-stop(0, #e3e3e3), color-stop(1, #ffffff));
	background: -ms-linear-gradient(bottom, #e3e3e3, #ffffff);
	background: -moz-linear-gradient(center bottom, #e3e3e3 0%, #ffffff 100%);
	background: -o-linear-gradient(#ffffff, #e3e3e3);
	border: 1px solid #aaa;
	-webkit-border-radius: 2px;
	-moz-border-radius: 2px;
	border-radius: 2px;
	-webkit-box-shadow: 0 1px 1px rgba(0,0,0,0.06);
	-moz-box-shadow: 0 1px 1px rgba(0,0,0,0.06);
	box-shadow: 0 1px 1px rgba(0,0,0,0.06);
	cursor: pointer;
	display: inline-block;
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffff', endColorstr='#e3e3e3', GradientType=0);
	margin: 0;
	margin-right: .1em;
	overflow: visible;
	padding: 5px;
	text-align: center;
	text-decoration: none !important;
	zoom: 1;
}

#panels .ui-button.ui-button-icon-only .ui-button-text,
#add-to-panels .ui-button.ui-button-icon-only .ui-button-text,
.ui-dialog.panels-admin-dialog .ui-dialog-titlebar-close.ui-button-icon-only .ui-button-text {
	display: none;
}

#panels .ui-button .ui-icon,
#add-to-panels .ui-button .ui-icon,
.ui-dialog.panels-admin-dialog .ui-dialog-titlebar-close .ui-icon {
	width: 8px;
	height: 8px;
	
	display: block;
}

#panels .ui-button .ui-icon.ui-icon-add,
#add-to-panels .ui-button .ui-icon.ui-icon-add,
.ui-dialog.panels-admin-dialog .ui-dialog-titlebar-close .ui-icon.ui-icon-add {
	background: url(images/icons/add.png);
}

#panels .ui-button .ui-icon.ui-icon-prebuilt,
#add-to-panels .ui-button .ui-icon.ui-icon-prebuilt,
.ui-dialog.panels-admin-dialog .ui-dialog-titlebar-close .ui-icon.ui-icon-prebuilt {
	background: url(images/icons/brush.png);
}

#panels .ui-button .ui-icon.ui-icon-columns,
#add-to-panels .ui-button .ui-icon.ui-icon-columns,
.ui-dialog.panels-admin-dialog .ui-dialog-titlebar-close .ui-icon.ui-icon-columns {
	background: url(images/icons/columns.png);
}

#panels .ui-button .ui-icon.ui-icon-settings,
#add-to-panels .ui-button .ui-icon.ui-icon-settings,
.ui-dialog.panels-admin-dialog .ui-dialog-titlebar-close .ui-icon.ui-icon-settings {
	background: url(images/icons/settings.png);
}

#panels .ui-button .ui-icon.ui-icon-move,
#add-to-panels .ui-button .ui-icon.ui-icon-move,
.ui-dialog.panels-admin-dialog .ui-dialog-titlebar-close .ui-icon.ui-icon-move {
	background: url(images/icons/move.png);
}

#panels .ui-button .ui-icon.ui-icon-remove,
#add-to-panels .ui-button .ui-icon.ui-icon-remove,
.ui-dialog.panels-admin-dialog .ui-dialog-titlebar-close .ui-icon.ui-icon-remove {
	background: url(images/icons/remove.png);
}

#panels .ui-button .ui-icon.ui-icon-gear,
#add-to-panels .ui-button .ui-icon.ui-icon-gear,
.ui-dialog.panels-admin-dialog .ui-dialog-titlebar-close .ui-icon.ui-icon-gear {
	background: url(images/icons/gear.png);
}

#panels .ui-button:hover,
#add-to-panels .ui-button:hover,
.ui-dialog.panels-admin-dialog .ui-dialog-titlebar-close:hover {
	background: #f0f0f0;
	background: -webkit-gradient(linear, left bottom, left top, color-stop(0, #f0f0f0), color-stop(1, #ffffff));
	background: -ms-linear-gradient(bottom, #f0f0f0, #ffffff);
	background: -moz-linear-gradient(center bottom, #f0f0f0 0%, #ffffff 100%);
	background: -o-linear-gradient(#ffffff, #f0f0f0);
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffff', endColorstr='#f0f0f0', GradientType=0);
}

#panels .ui-button:active,
#add-to-panels .ui-button:active,
.ui-dialog.panels-admin-dialog .ui-dialog-titlebar-close:active {
	background: #ffffff;
	background: -webkit-gradient(linear, left bottom, left top, color-stop(0, #ffffff), color-stop(1, #ffffff));
	background: -ms-linear-gradient(bottom, #ffffff, #ffffff);
	background: -moz-linear-gradient(center bottom, #ffffff 0%, #ffffff 100%);
	background: -o-linear-gradient(#ffffff, #ffffff);
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffff', endColorstr='#ffffff', GradientType=0);
}

/* jQuery UI Dialog */

.ui-dialog.panels-admin-dialog {
	background: white;
	border: 1px solid #D0D0D0;
	-webkit-border-radius: 3px;
	-moz-border-radius: 3px;
	border-radius: 3px;
	-webkit-box-shadow: 0 0 5px rgba(0,0,0,0.3);
	-moz-box-shadow: 0 0 5px rgba(0,0,0,0.3);
	box-shadow: 0 0 5px rgba(0,0,0,0.3);
	padding: 0 !important;
	z-index: 1001;
}

.ui-dialog.panels-admin-dialog .ui-dialog-buttonpane {
	background: #f1f1f1;
	border: none;
	border-top: 1px solid #dddddd;
}

.ui-dialog.panels-admin-dialog .ui-dialog-titlebar {
	position: relative;
	
	background: #e0e0e0;
	background: #ededed;
	background: -webkit-gradient(linear, left bottom, left top, color-stop(0, #e0e0e0), color-stop(1, #ededed));
	background: -ms-linear-gradient(bottom, #e0e0e0, #ededed);
	background: -moz-linear-gradient(center bottom, #e0e0e0 0%, #ededed 100%);
	background: -o-linear-gradient(#ededed, #e0e0e0);
	-moz-background-clip: padding-box;
	-webkit-background-clip: padding-box;
	background-clip: padding-box;
	border: 1px solid #ccc;
	-webkit-border-bottom-left-radius: 0;
	border-bottom-left-radius: 0;
	-webkit-border-bottom-right-radius: 0;
	border-bottom-right-radius: 0;
	border-color: #ccc #ccc #c0c0c0 #ccc;
	-webkit-border-top-left-radius: 3px;
	border-top-left-radius: 3px;
	-webkit-border-top-right-radius: 3px;
	border-top-right-radius: 3px;
	color: #505050;
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ededed', endColorstr='#e0e0e0', GradientType=0);
	font-size: 13px;
	font-weight: 600;
	line-height: 1;
	margin: -1px -1px 0 -1px;
	padding: 10px;
	text-shadow: rgba(255, 255, 255, 0.6) 0px 1px 0px;
	-moz-border-radius-topright: 3px;
	-moz-border-radius-bottomright: 0;
	-moz-border-radius-bottomleft: 0;
	-moz-border-radius-topleft: 3px;
}

.ui-dialog.panels-admin-dialog .ui-dialog-titlebar .ui-dialog-titlebar-close {
	position: absolute;
	top: 50%;
	right: 8px;
	
	margin-top: -10px;
}

.ui-dialog.panels-admin-dialog .ui-dialog-titlebar .ui-dialog-titlebar-close .ui-icon {
	width: 8px;
	height: 8px;
	
	background: url(images/icons/close.png);
	display: block;
}

.ui-dialog.panels-admin-dialog .ui-dialog-content {
	max-height: 600px;
	overflow: auto;
	padding: 12px;
}

/* custom */
.ui-dialog.panels-admin-dialog .ui-dialog-content p:first-child {
	margin-top: 0;
}

.ui-dialog.panels-admin-dialog .ui-dialog-content *:last-child {
	margin-bottom: 0;
}

.ui-dialog.panels-admin-dialog .ui-dialog-content label {
	color: #333;
	display: inline-block;
}

.ui-dialog.panels-admin-dialog .ui-dialog-content p:hover label {
	color: #1c1c1c;
}

.ui-dialog.panels-admin-dialog .ui-dialog-content textarea,
.ui-dialog.panels-admin-dialog .ui-dialog-content input.widefat {
	-ms-box-sizing: border-box;
	-moz-box-sizing: border-box;
	-webkit-box-sizing: border-box;
	box-sizing: border-box;
	margin-top: 6px;
}

.ui-dialog.panels-admin-dialog .ui-dialog-content p {
	margin: 15px 0 5px 0;
}

.ui-dialog.panels-admin-dialog .ui-dialog-content p.description {
	margin-top: 5px;
}

.ui-dialog.panels-admin-dialog .ui-dialog-buttonpane {
	padding: 5px;
}

.ui-dialog.panels-admin-dialog .ui-dialog-buttonpane .ui-button {
	background: #21759b;
	background: -webkit-gradient(linear, left bottom, left top, color-stop(0, #21759b), color-stop(1, #2e9fd2));
	background: -ms-linear-gradient(bottom, #21759b, #2e9fd2);
	background: -moz-linear-gradient(center bottom, #21759b 0%, #2e9fd2 100%);
	background: -o-linear-gradient(#2e9fd2, #21759b);
	border: 1px solid #1b607f;
	-webkit-border-radius: 2px;
	-moz-border-radius: 2px;
	border-radius: 2px;
	-webkit-box-shadow: inset 0 1px 0 rgba(120,200,230,0.6);
	-moz-box-shadow: inset 0 1px 0 rgba(120,200,230,0.6);
	box-shadow: inset 0 1px 0 rgba(120,200,230,0.6);
	color: #fff;
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#2e9fd2', endColorstr='#21759b', GradientType=0);
	margin-right: 8px;
	padding: 6px 12px;
	text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.3);
}

.ui-dialog.panels-admin-dialog.panels-ajax-loading .ui-dialog-buttonpane {
	background: #f1f1f1 url(./images/ajax-loader.gif) no-repeat 15px 17px;
}

#so-panels-recommended-plugins {
	text-align: center;
}

#so-panels-recommended-plugins a {
	background: #3288d4;
	background: -webkit-gradient(linear, left bottom, left top, color-stop(0, #3288d4), color-stop(1, #43aee0));
	background: -ms-linear-gradient(bottom, #3288d4, #43aee0);
	background: -moz-linear-gradient(center bottom, #3288d4 0%, #43aee0 100%);
	background: -o-linear-gradient(#43aee0, #3288d4);
	border: 1px solid #2474a9;
	-webkit-border-radius: 2px;
	-moz-border-radius: 2px;
	border-radius: 2px;
	-webkit-box-shadow: inset 0 1px 0 #69d2ee;
	-moz-box-shadow: inset 0 1px 0 #69d2ee;
	box-shadow: inset 0 1px 0 #69d2ee;
	color: #edffff;
	display: inline-block;
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#43aee0', endColorstr='#3288d4', GradientType=0);
	font-size: 14px;
	font-weight: bold;
	padding: 12px 18px;
	text-decoration: none;
	text-shadow: 0 1px 1px rgba(0, 0, 0, 0.5);
}

#so-panels-recommended-plugins small {
	color: #666;
	display: block;
	font-size: 11px;
	margin-top: 4px;
}

#panels-row-style-select {
	position: absolute;
	
	background: #3f3f3f;
	-webkit-border-radius: 3px;
	-moz-border-radius: 3px;
	border-radius: 3px;
	display: none;
	min-width: 250px;
	z-index: 1000;
}

#panels-row-style-select ul {
	list-style: none;
	margin: 0;
	padding: 8px;
}

#panels-row-style-select ul li {
	background: #fefefe;
	background: -webkit-gradient(linear, left bottom, left top, color-stop(0, #d6d6d6), color-stop(1, #fefefe));
	background: -ms-linear-gradient(bottom, #d6d6d6, #fefefe);
	background: -moz-linear-gradient(center bottom, #d6d6d6 0%, #fefefe 100%);
	background: -o-linear-gradient(#fefefe, #d6d6d6);
	-webkit-border-radius: 2px;
	-moz-border-radius: 2px;
	border-radius: 2px;
	-webkit-box-shadow: 0 1px 1px rgba(0,0,0,0.4);
	-moz-box-shadow: 0 1px 1px rgba(0,0,0,0.4);
	box-shadow: 0 1px 1px rgba(0,0,0,0.4);
	color: #474747;
	cursor: pointer;
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fefefe', endColorstr='#d6d6d6', GradientType=0);
	font-size: 11px;
	font-weight: bold;
	line-height: 1em;
	padding: 8px;
	text-shadow: 0 1px 0 rgba(255, 255, 255, 0.4);
	-webkit-transition: all 0.2s ease;
	-moz-transition: all 0.2s ease;
	-o-transition: all 0.2s ease;
	transition: all 0.2s ease;
}

#panels-row-style-select ul li:last-child {
	margin-bottom: 0;
}

#panels-row-style-select ul li:hover,
#panels-row-style-select ul li.selected {
	background: #7fbadb;
	background: -webkit-gradient(linear, left bottom, left top, color-stop(0, #5692b3), color-stop(1, #7fbadb));
	background: -ms-linear-gradient(bottom, #5692b3, #7fbadb);
	background: -moz-linear-gradient(center bottom, #5692b3 0%, #7fbadb 100%);
	background: -o-linear-gradient(#7fbadb, #5692b3);
	color: #004f70;
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#7fbadb', endColorstr='#5692b3', GradientType=0);
}

#panels-row-style-select:before {
	position: absolute;
	top: -4px;
	right: 32px;
	width: 8px;
	height: 4px;
	
	background: url(./images/pointer.png);
	content: '';
	display: block;
}


/* custom */
#panels-container .no-container .panels-container .panel {
	background: #fff;
}

#panels-container .no-container .panels-container { 
	background: #e2e2e2;
}

.ui-dialog.panels-admin-dialog .ui-dialog-content label { margin-right: 8px; }

.ui-dialog.panels-admin-dialog .ui-dialog-content .widefat {
	-ms-box-sizing: border-box;
	-moz-box-sizing: border-box;
	-webkit-box-sizing: border-box;
	box-sizing: border-box;
	margin-top: 6px;
}

.ui-dialog.panels-admin-dialog .ui-dialog-content > div {
	margin: 15px 0 5px 0;	
}

.panels-admin-dialog hr { margin-top: 20px; }

#TB_window, #TB_overlay { z-index:10000 !important; }
